Struct amazon_sp_vendor_invoices::models::invoice_item::InvoiceItem
source · [−]pub struct InvoiceItem {
pub item_sequence_number: i32,
pub amazon_product_identifier: Option<String>,
pub vendor_product_identifier: Option<String>,
pub invoiced_quantity: Box<ItemQuantity>,
pub net_cost: Box<Money>,
pub purchase_order_number: Option<String>,
pub hsn_code: Option<String>,
pub credit_note_details: Option<Box<CreditNoteDetails>>,
pub tax_details: Option<Vec<TaxDetails>>,
pub charge_details: Option<Vec<ChargeDetails>>,
pub allowance_details: Option<Vec<AllowanceDetails>>,
}Expand description
InvoiceItem : Details of the item being invoiced.
Fields
item_sequence_number: i32Unique number related to this line item.
amazon_product_identifier: Option<String>Amazon Standard Identification Number (ASIN) of an item.
vendor_product_identifier: Option<String>The vendor selected product identifier of the item. Should be the same as was provided in the purchase order.
invoiced_quantity: Box<ItemQuantity>net_cost: Box<Money>purchase_order_number: Option<String>The Amazon purchase order number for this invoiced line item. Formatting Notes: 8-character alpha-numeric code. This value is mandatory only when invoiceType is Invoice, and is not required when invoiceType is CreditNote.
hsn_code: Option<String>HSN Tax code. The HSN number cannot contain alphabets.
credit_note_details: Option<Box<CreditNoteDetails>>tax_details: Option<Vec<TaxDetails>>Individual tax details per line item.
charge_details: Option<Vec<ChargeDetails>>Individual charge details per line item.
allowance_details: Option<Vec<AllowanceDetails>>Individual allowance details per line item.
Implementations
sourceimpl InvoiceItem
impl InvoiceItem
sourcepub fn new(
item_sequence_number: i32,
invoiced_quantity: ItemQuantity,
net_cost: Money
) -> InvoiceItem
pub fn new(
item_sequence_number: i32,
invoiced_quantity: ItemQuantity,
net_cost: Money
) -> InvoiceItem
Details of the item being invoiced.